@@ -3,14 +3,14 @@ package net.thunderbird.app.common.account.data
 import kotlinx.coroutines.flow.Flow
 import kotlinx.coroutines.flow.firstOrNull
 import kotlinx.coroutines.flow.map
-import net.thunderbird.core.android.account.LegacyAccountWrapperManager
+import net.thunderbird.core.android.account.LegacyAccountManager
 import net.thunderbird.feature.account.AccountId
 import net.thunderbird.feature.account.core.AccountCoreExternalContract.AccountProfileLocalDataSource
 import net.thunderbird.feature.account.profile.AccountProfile
 import net.thunderbird.feature.account.storage.mapper.AccountProfileDataMapper
 
 internal class DefaultAccountProfileLocalDataSource(
-    private val accountManager: LegacyAccountWrapperManager,
+    private val accountManager: LegacyAccountManager,
     private val dataMapper: AccountProfileDataMapper,
 ) : AccountProfileLocalDataSource {
 
