@@ -2,6 +2,7 @@ package net.thunderbird.app.common.feature
 
 import app.k9mail.feature.launcher.FeatureLauncherExternalContract
 import app.k9mail.feature.launcher.di.featureLauncherModule
+import net.thunderbird.app.common.feature.mail.appCommonFeatureMailModule
 import net.thunderbird.feature.navigation.drawer.api.NavigationDrawerExternalContract
 import net.thunderbird.feature.notification.impl.inject.featureNotificationModule
 import org.koin.android.ext.koin.androidContext
@@ -10,6 +11,7 @@ import org.koin.dsl.module
 internal val appCommonFeatureModule = module {
     includes(featureLauncherModule)
     includes(featureNotificationModule)
+    includes(appCommonFeatureMailModule)
 
     factory<FeatureLauncherExternalContract.AccountSetupFinishedLauncher> {
         AccountSetupFinishedLauncher(
