@@ -1,5 +1,6 @@
 package app.k9mail.featureflag
 
+import com.fsck.k9.ui.messagelist.MessageListFeatureFlags
 import net.thunderbird.core.featureflag.FeatureFlag
 import net.thunderbird.core.featureflag.FeatureFlagFactory
 import net.thunderbird.core.featureflag.FeatureFlagKey
@@ -14,8 +15,9 @@ class K9FeatureFlagFactory : FeatureFlagFactory {
             FeatureFlag("email_notification_default".toFeatureFlagKey(), enabled = true),
             FeatureFlag("enable_dropdown_drawer".toFeatureFlagKey(), enabled = true),
             FeatureFlag("enable_dropdown_drawer_ui".toFeatureFlagKey(), enabled = true),
-            FeatureFlag(FeatureFlagKey.DisplayInAppNotifications, enabled = true),
-            FeatureFlag(FeatureFlagKey.UseNotificationSenderForSystemNotifications, enabled = true),
+            FeatureFlag(FeatureFlagKey.DisplayInAppNotifications, enabled = false),
+            FeatureFlag(FeatureFlagKey.UseNotificationSenderForSystemNotifications, enabled = false),
+            FeatureFlag(MessageListFeatureFlags.UseComposeForMessageListItems, enabled = false),
         )
     }
 }
