@@ -5,18 +5,17 @@ import app.k9mail.feature.funding.featureFundingModule
 import app.k9mail.feature.migration.launcher.featureMigrationModule
 import app.k9mail.feature.onboarding.migration.onboardingMigrationModule
 import app.k9mail.feature.telemetry.telemetryModule
-import net.thunderbird.app.common.feature.featureLauncherModule
 import net.thunderbird.feature.account.settings.featureAccountSettingsModule
+import net.thunderbird.feature.mail.message.list.featureMessageListModule
 import org.koin.dsl.module
 
 val featureModule = module {
-    includes(featureLauncherModule)
-
     includes(featureAccountSettingsModule)
     includes(telemetryModule)
     includes(featureFundingModule)
     includes(onboardingMigrationModule)
     includes(featureMigrationModule)
+    includes(featureMessageListModule)
 
     single<FundingSettings> { K9FundingSettings() }
 }
