@@ -3,7 +3,9 @@ val kotlinEditorConfigOverride = mapOf(
     "ktlint_code_style" to "intellij_idea",
     "ktlint_ignore_back_ticked_identifier" to "true",
     "ktlint_function_naming_ignore_when_annotated_with" to "Composable",
-    "ktlint_standard_property-naming" to "disabled",
+    "ktlint_standard_class-signature" to "disabled",
+    "ktlint_standard_function-expression-body" to "disabled",
     "ktlint_standard_function-signature" to "disabled",
     "ktlint_standard_parameter-list-spacing" to "disabled",
+    "ktlint_standard_property-naming" to "disabled",
 )
