@@ -3,6 +3,9 @@ package app.k9mail.core.ui.compose.designsystem.atom.textfield
 import androidx.compose.foundation.text.KeyboardOptions
 import androidx.compose.runtime.Composable
 import androidx.compose.ui.Modifier
+import androidx.compose.ui.autofill.ContentType
+import androidx.compose.ui.semantics.contentType
+import androidx.compose.ui.semantics.semantics
 import androidx.compose.ui.text.input.KeyboardType
 import androidx.compose.material3.OutlinedTextField as Material3OutlinedTextField
 
@@ -21,13 +24,13 @@ fun TextFieldOutlinedEmailAddress(
     Material3OutlinedTextField(
         value = value,
         onValueChange = stripLineBreaks(onValueChange),
-        modifier = modifier,
+        modifier = modifier.semantics { contentType = ContentType.EmailAddress },
         enabled = isEnabled,
         label = selectLabel(label, isRequired),
         readOnly = isReadOnly,
         isError = hasError,
         keyboardOptions = KeyboardOptions(
-            autoCorrect = false,
+            autoCorrectEnabled = false,
             keyboardType = KeyboardType.Email,
         ),
         singleLine = true,
