@@ -1,8 +1,8 @@
 package net.thunderbird.feature.account.core
 
 import kotlinx.coroutines.flow.Flow
-import net.thunderbird.feature.account.api.AccountId
-import net.thunderbird.feature.account.api.profile.AccountProfile
+import net.thunderbird.feature.account.AccountId
+import net.thunderbird.feature.account.profile.AccountProfile
 
 interface AccountCoreExternalContract {
 
