@@ -3,7 +3,7 @@ package net.thunderbird.feature.account.settings.impl
 import androidx.navigation.NavGraphBuilder
 import androidx.navigation.toRoute
 import app.k9mail.core.ui.compose.navigation.deepLinkComposable
-import net.thunderbird.feature.account.api.AccountId
+import net.thunderbird.feature.account.AccountIdFactory
 import net.thunderbird.feature.account.settings.api.AccountSettingsNavigation
 import net.thunderbird.feature.account.settings.api.AccountSettingsRoute
 import net.thunderbird.feature.account.settings.impl.ui.general.GeneralSettingsScreen
@@ -20,7 +20,7 @@ internal class DefaultAccountSettingsNavigation : AccountSettingsNavigation {
                 basePath = AccountSettingsRoute.GeneralSettings.Companion.BASE_PATH,
             ) { backStackEntry ->
                 val generalSettingsRoute = backStackEntry.toRoute<AccountSettingsRoute.GeneralSettings>()
-                val accountId = AccountId.from(generalSettingsRoute.accountId)
+                val accountId = AccountIdFactory.of(generalSettingsRoute.accountId)
 
                 GeneralSettingsScreen(
                     accountId = accountId,
