@@ -14,15 +14,15 @@ import kotlinx.coroutines.flow.combine
 import kotlinx.coroutines.flow.flatMapLatest
 import kotlinx.coroutines.flow.flowOn
 import kotlinx.coroutines.launch
-import net.thunderbird.core.android.account.AccountManager
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
+import net.thunderbird.core.android.account.LegacyAccountDtoManager
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.DomainContract.UseCase
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayAccount
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.MailDisplayAccount
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.UnifiedDisplayAccount
 
 internal class GetDisplayAccounts(
-    private val accountManager: AccountManager,
+    private val accountManager: LegacyAccountDtoManager,
     private val messageCountsProvider: MessageCountsProvider,
     private val messageListRepository: MessageListRepository,
     private val coroutineContext: CoroutineContext = Dispatchers.IO,
@@ -66,7 +66,7 @@ internal class GetDisplayAccounts(
         return listOf(unified) + accounts
     }
 
-    private fun getMessageCountsFlow(account: LegacyAccount): Flow<MessageCounts> {
+    private fun getMessageCountsFlow(account: LegacyAccountDto): Flow<MessageCounts> {
         return callbackFlow {
             send(messageCountsProvider.getMessageCounts(account))
 
