@@ -4,11 +4,13 @@ import net.thunderbird.feature.notification.api.NotificationId
 import net.thunderbird.feature.notification.api.content.SystemNotification
 import net.thunderbird.feature.notification.api.receiver.NotificationNotifier
 
-class FakeSystemNotificationNotifier : NotificationNotifier<SystemNotification> {
+open class FakeSystemNotificationNotifier : NotificationNotifier<SystemNotification> {
     override suspend fun show(
         id: NotificationId,
         notification: SystemNotification,
     ) = Unit
 
+    override suspend fun dismiss(id: NotificationId) = Unit
+
     override fun dispose() = Unit
 }
