@@ -2,10 +2,10 @@ package app.k9mail.feature.onboarding.permissions.ui
 
 import androidx.compose.runtime.Composable
 import app.k9mail.core.android.permissions.PermissionState
-import app.k9mail.core.common.provider.BrandNameProvider
 import app.k9mail.core.ui.compose.common.annotation.PreviewDevices
 import app.k9mail.core.ui.compose.designsystem.PreviewWithTheme
 import kotlinx.coroutines.Dispatchers
+import net.thunderbird.core.common.provider.BrandNameProvider
 
 @Composable
 @PreviewDevices
