@@ -3,13 +3,13 @@ package com.fsck.k9.backend
 import com.fsck.k9.backend.api.Backend
 import com.fsck.k9.mail.ServerSettings
 import java.util.concurrent.CopyOnWriteArraySet
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
 class BackendManager(private val backendFactories: Map<String, BackendFactory>) {
     private val backendCache = mutableMapOf<String, BackendContainer>()
     private val listeners = CopyOnWriteArraySet<BackendChangedListener>()
 
-    fun getBackend(account: LegacyAccount): Backend {
+    fun getBackend(account: LegacyAccountDto): Backend {
         val newBackend = synchronized(backendCache) {
             val container = backendCache[account.uuid]
             if (container != null && isBackendStillValid(container, account)) {
@@ -30,12 +30,12 @@ class BackendManager(private val backendFactories: Map<String, BackendFactory>)
         return newBackend
     }
 
-    private fun isBackendStillValid(container: BackendContainer, account: LegacyAccount): Boolean {
+    private fun isBackendStillValid(container: BackendContainer, account: LegacyAccountDto): Boolean {
         return container.incomingServerSettings == account.incomingServerSettings &&
             container.outgoingServerSettings == account.outgoingServerSettings
     }
 
-    fun removeBackend(account: LegacyAccount) {
+    fun removeBackend(account: LegacyAccountDto) {
         synchronized(backendCache) {
             backendCache.remove(account.uuid)
         }
@@ -43,7 +43,7 @@ class BackendManager(private val backendFactories: Map<String, BackendFactory>)
         notifyListeners(account)
     }
 
-    private fun createBackend(account: LegacyAccount): Backend {
+    private fun createBackend(account: LegacyAccountDto): Backend {
         val serverType = account.incomingServerSettings.type
         val backendFactory = backendFactories[serverType] ?: error("Unsupported account type")
         return backendFactory.createBackend(account)
@@ -57,7 +57,7 @@ class BackendManager(private val backendFactories: Map<String, BackendFactory>)
         listeners.remove(listener)
     }
 
-    private fun notifyListeners(account: LegacyAccount) {
+    private fun notifyListeners(account: LegacyAccountDto) {
         for (listener in listeners) {
             listener.onBackendChanged(account)
         }
@@ -71,5 +71,5 @@ private data class BackendContainer(
 )
 
 fun interface BackendChangedListener {
-    fun onBackendChanged(account: LegacyAccount)
+    fun onBackendChanged(account: LegacyAccountDto)
 }
