@@ -2,12 +2,12 @@ package com.fsck.k9.mailstore
 
 import app.k9mail.legacy.mailstore.FolderSettings
 import com.fsck.k9.Preferences
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
 /**
  * Provides imported folder settings if available, otherwise default values.
  */
-class FolderSettingsProvider(val preferences: Preferences, val account: LegacyAccount) {
+class FolderSettingsProvider(val preferences: Preferences, val account: LegacyAccountDto) {
     fun getFolderSettings(folderServerId: String): FolderSettings {
         val storage = preferences.storage
         val prefix = "${account.uuid}.$folderServerId"
