@@ -1,13 +1,13 @@
 package com.fsck.k9.mailstore;
 
 
-import net.thunderbird.core.android.account.LegacyAccount;
+import net.thunderbird.core.android.account.LegacyAccountDto;
 
 
 /**
  * Helper to allow accessing classes and methods that aren't visible or accessible to the 'migrations' package
  */
 public interface MigrationsHelper {
-    LegacyAccount getAccount();
+    LegacyAccountDto getAccount();
     void saveAccount();
 }
