@@ -2,10 +2,10 @@ package com.fsck.k9.preferences
 
 import app.k9mail.legacy.mailstore.FolderRepository
 import app.k9mail.legacy.mailstore.RemoteFolderDetails
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
 class FolderSettingsProvider(private val folderRepository: FolderRepository) {
-    fun getFolderSettings(account: LegacyAccount): List<FolderSettings> {
+    fun getFolderSettings(account: LegacyAccountDto): List<FolderSettings> {
         return folderRepository.getRemoteFolderDetails(account)
             .filterNot { it.containsOnlyDefaultValues() }
             .map { it.toFolderSettings() }
