@@ -10,7 +10,7 @@ import com.fsck.k9.backend.api.BackendStorage
 import com.fsck.k9.mail.AuthType
 import com.fsck.k9.mail.ConnectionSecurity
 import com.fsck.k9.mail.ServerSettings
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 import org.junit.After
 import org.junit.Test
 import org.koin.core.component.inject
@@ -23,7 +23,7 @@ class K9BackendDefaultStorageTest : K9RobolectricTest() {
     val messageStoreManager: MessageStoreManager by inject()
     val saveMessageDataCreator: SaveMessageDataCreator by inject()
 
-    val account: LegacyAccount = createAccount()
+    val account: LegacyAccountDto = createAccount()
     val backendStorage = createBackendStorage()
 
     @After
@@ -66,7 +66,7 @@ class K9BackendDefaultStorageTest : K9RobolectricTest() {
     }
 
     @Suppress("ForbiddenComment")
-    fun createAccount(): LegacyAccount {
+    fun createAccount(): LegacyAccountDto {
         // FIXME: This is a hack to get Preferences into a state where it's safe to call newAccount()
         preferences.clearAccounts()
 
