@@ -9,7 +9,7 @@ import assertk.assertions.isFalse
 import assertk.assertions.isTrue
 import com.fsck.k9.K9
 import com.fsck.k9.K9.NotificationQuickDelete
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 import org.junit.Test
 
 class SingleMessageNotificationDataCreatorTest {
@@ -257,8 +257,8 @@ class SingleMessageNotificationDataCreatorTest {
         K9.isConfirmSpam = confirm
     }
 
-    private fun createAccount(): LegacyAccount {
-        return LegacyAccount("00000000-0000-0000-0000-000000000000").apply {
+    private fun createAccount(): LegacyAccountDto {
+        return LegacyAccountDto("00000000-0000-0000-0000-000000000000").apply {
             accountNumber = 42
         }
     }
