@@ -8,7 +8,7 @@ android {
 
 dependencies {
     implementation(projects.core.android.account)
-    implementation(projects.feature.search)
+    implementation(projects.feature.search.implLegacy)
 
     implementation(projects.mail.common)
     implementation(projects.backend.api)
