@@ -6,7 +6,8 @@ import com.fsck.k9.Preferences
 import com.fsck.k9.backend.BackendManager
 import com.fsck.k9.controller.MessagingController
 import com.fsck.k9.mailstore.LocalStoreProvider
-import net.thunderbird.core.android.account.LegacyAccount
+import com.fsck.k9.preferences.UnifiedInboxConfigurator
+import net.thunderbird.core.android.account.LegacyAccountDto
 import net.thunderbird.core.logging.legacy.Log
 
 /**
@@ -18,6 +19,7 @@ class AccountRemover(
     private val backendManager: BackendManager,
     private val localKeyStoreManager: LocalKeyStoreManager,
     private val preferences: Preferences,
+    private val unifiedInboxConfigurator: UnifiedInboxConfigurator,
 ) {
 
     fun removeAccount(accountUuid: String) {
@@ -38,11 +40,12 @@ class AccountRemover(
 
         removeCertificates(account)
         Core.setServicesEnabled()
+        unifiedInboxConfigurator.configureUnifiedInbox()
 
         Log.v("Finished removing account '%s'.", accountName)
     }
 
-    private fun removeLocalStore(account: LegacyAccount) {
+    private fun removeLocalStore(account: LegacyAccountDto) {
         try {
             val localStore = localStoreProvider.getInstance(account)
             localStore.delete()
@@ -52,10 +55,10 @@ class AccountRemover(
             // Ignore, this may lead to localStores on sd-cards that are currently not inserted to be left
         }
 
-        localStoreProvider.removeInstance(account)
+        localStoreProvider.removeInstance(account.uuid)
     }
 
-    private fun removeBackend(account: LegacyAccount) {
+    private fun removeBackend(account: LegacyAccountDto) {
         try {
             backendManager.removeBackend(account)
         } catch (e: Exception) {
@@ -63,7 +66,7 @@ class AccountRemover(
         }
     }
 
-    private fun removeCertificates(account: LegacyAccount) {
+    private fun removeCertificates(account: LegacyAccountDto) {
         try {
             localKeyStoreManager.deleteCertificates(account)
         } catch (e: Exception) {
