@@ -10,7 +10,7 @@ import androidx.navigation.ui.setupActionBarWithNavController
 import com.fsck.k9.ui.R
 import com.fsck.k9.ui.base.K9Activity
 import com.fsck.k9.ui.base.extensions.findNavController
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
 class ManageFoldersActivity : K9Activity() {
     private lateinit var navController: NavController
@@ -50,7 +50,7 @@ class ManageFoldersActivity : K9Activity() {
         private const val EXTRA_ACCOUNT = "account"
 
         @JvmStatic
-        fun launch(activity: Activity, account: LegacyAccount) {
+        fun launch(activity: Activity, account: LegacyAccountDto) {
             val intent = Intent(activity, ManageFoldersActivity::class.java).apply {
                 putExtra(EXTRA_ACCOUNT, account.uuid)
             }
