@@ -5,11 +5,15 @@ import com.fsck.k9.mailstore.AttachmentResolver
 import com.fsck.k9.message.ReplyActionStrategy
 import com.fsck.k9.ui.helper.RelativeDateTimeFormatter
 import com.fsck.k9.view.MessageWebView.OnPageFinishedListener
+import kotlin.time.ExperimentalTime
 import org.koin.dsl.module
 
 val viewModule = module {
     single { WebViewConfigProvider(themeManager = get(), generalSettingsManager = get()) }
-    factory { RelativeDateTimeFormatter(context = get(), clock = get()) }
+    factory {
+        @OptIn(ExperimentalTime::class)
+        RelativeDateTimeFormatter(context = get(), clock = get())
+    }
     factory { ReplyToParser() }
     factory { ReplyActionStrategy(replyRoParser = get()) }
     factory { (attachmentResolver: AttachmentResolver?, onPageFinishedListener: OnPageFinishedListener?) ->
